from netforce.model import Model, fields, get_model
from netforce.access import get_active_company

class Department(Model):
    _name="clinic.department"
    _string="Department"
    _key=['code']

    _fields={
        "name": fields.Char("Name",required=True,search=True),
        "code": fields.Char("Code",required=True,search=True),
        "parent_id": fields.Many2One("clinic.department", "Parent"),
        'company_id': fields.Many2One("company","Company"),
        'branch_id': fields.Many2One("clinic.branch","Branch"),
        "pick_out_journal_id": fields.Many2One("stock.journal","Stock Journal",required=True),
        'patients':  fields.One2Many("clinic.patient","department_id","Patients"),
        'staffs':  fields.One2Many("clinic.staff","department_id","Staffs"),
        'active': fields.Boolean("Active"),
    }
    
    def _get_branch(self,context={}):
        b_ids=get_model('clinic.branch').search([])
        if b_ids:
            return b_ids[0]

    _defaults={
        'company_id': lambda *a: get_active_company(),
        'branch_id': _get_branch,
        'active': True,
    }

    _order="code"
    
    def create_profile(self,ids,context={}):
        for obj in self.browse(ids):
            code=obj.code or ''
            pf_ids=get_model('profile').search(['code','=',code])
            if pf_ids:
                raise Exception("Profile %s is already exist"%(code))
                return
            except_perms=['Clinic Menu Settings','Clinic Staff Tab Accounting']
            other_perms=[]
            for otp in get_model('permission').search(['name','ilike','clinic'],['name']):
                name=otp['name']
                if name in except_perms:
                    continue
                other_perms.append(otp['id'])
            get_model('profile').create({
                'code': code,
                'name': code,
                'other_perms': [('set',other_perms)],
            })
            print("create profile %s"%(code))

    def share_access(self,ids,context={}):
        obj=self.browse(ids)[0]
        obj.create_profile()
        return {
            'next': {
                'name': 'clinic_department',
                'active_id': obj.id,
                'mode': 'form',
            },
            'flash': 'Department % s is shared sucessfully'%obj.name,
        }

Department.register()
